pyLBM.Geometry
==============

.. currentmodule:: pyLBM

.. autoclass:: Geometry

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Geometry.add_elem
         Geometry.list_of_elements_labels
         Geometry.list_of_labels
         Geometry.visualize



   

